<?php

/**
 * Provide a admin area help info view for the plugin
 *
 * This file is used to markup the admin-facing aspects of the plugin.
 *
 * @link       https://www.chiptuningreseller.com
 * @since      3.1.1
 *
 * @package    Ctr
 * @subpackage Ctr/admin/partials
 */
if (isset($_GET['edit_file'])) {
    $file = wp_unslash($_GET['edit_file']);
}

// Try to get the file via the catalogdata
if(!isset($file) && is_array($catalogData['template_files'])) {
    $file = wp_unslash(array_values($catalogData['template_files'])[1]);
}

if(isset($file)) {
    $loadedFile = ((is_array($file)) && (isset($file['file']))) ? $file['file'] : $file;

    $base_dir = wp_upload_dir()['basedir'] . '/ctr/custom_templates/';
    $real_file = is_array($file) ? $file['file'] : $base_dir . $file;
    $file_error = false;
    
    $editable_extensions = ['php', 'txt', 'css'];
    
    if (!empty($posted_content)) {
        $content = $posted_content;
    } else {
        $content = file_get_contents($real_file);
    }
    
    $file_content_type = mime_content_type($real_file) ?? 'application/x-httpd-php';
    if($file_content_type == 'text/plain') {
        $file_content_type = 'text/css';
    }
    
    $settings = array(
        'codeEditor' => wp_enqueue_code_editor(['file' => $real_file]),
    );
    
    wp_enqueue_style('wp-codemirror');
    wp_add_inline_script('wp-theme-plugin-editor', sprintf('jQuery( function( $ ) { wp.themePluginEditor.init( $( "#template" ), %s ); } )', wp_json_encode($settings)));
    wp_add_inline_script('wp-theme-plugin-editor', 'wp.themePluginEditor.themeOrPlugin = "plugin";');

    $plugin_files = get_plugin_files('ctr/custom_templates');
}

/**
 * Enqueue scripts for the CodeEditor
 */



/** The file doesn't exist. Give an error and help */
if ((!isset($real_file)) || (!is_file($real_file))) {
    echo sprintf('<p>%s</p><a class="button button-primary" href="#" id="copyTemplates">Click here to copy the templates to edit them</a>', __('Something went wrong, looks like the custom templates folder does not exist yet. Please activate it by clicking the button below...'));
    echo sprintf('<p>%s</p>', __('File does not exist! Please double check the name and try again.'));
    $file_error = true;

} else {
    // Get the extension of the file.
    if (preg_match('/\.([^.]+)$/', $real_file, $matches)) {
        $ext = strtolower($matches[1]);
        // If extension is not in the acceptable list, skip it.
        if (!in_array($ext, $editable_extensions)) {
            wp_die(sprintf('<p>%s</p>', __('Files of this type are not editable.')));
        }
    }
}

?>
<script id='code-editor-js-after'>
jQuery.extend( wp.codeEditor.defaultSettings, {"codemirror":{"indentUnit":4,"indentWithTabs":true,"inputStyle":"contenteditable","lineNumbers":true,"lineWrapping":true,"styleActiveLine":true,"continueComments":true,"extraKeys":{"Ctrl-Space":"autocomplete","Ctrl-\/":"toggleComment","Cmd-\/":"toggleComment","Alt-F":"findPersistent","Ctrl-F":"findPersistent","Cmd-F":"findPersistent"},"direction":"ltr","gutters":[],"mode":"php","autoCloseBrackets":true,"autoCloseTags":true,"matchBrackets":true,"matchTags":{"bothTags":true}},"csslint":{"errors":true,"box-model":true,"display-property-grouping":true,"duplicate-properties":true,"known-properties":true,"outline-none":true},"jshint":{"boss":true,"curly":true,"eqeqeq":true,"eqnull":true,"es3":true,"expr":true,"immed":true,"noarg":true,"nonbsp":true,"onevar":true,"quotmark":"single","trailing":true,"undef":true,"unused":true,"browser":true,"globals":{"_":false,"Backbone":false,"jQuery":false,"JSON":false,"wp":false}},"htmlhint":{"tagname-lowercase":true,"attr-lowercase":true,"attr-value-double-quotes":false,"doctype-first":false,"tag-pair":true,"spec-char-escape":true,"id-unique":true,"src-not-empty":true,"attr-no-duplication":true,"alt-require":true,"space-tab-mixed-disabled":"tab","attr-unsafe-chars":true}} );
</script>
<!-- This file should primarily consist of HTML with a little bit of PHP. -->
<?php if(!$file_error) { ?>
<div id="chiptuningreseller-settings-container">
    <form class='mar-plugin-form' method="post" action="" id="template" enctype="multipart/form-data" style="background: white;padding: 20px;border: 1px solid #ddd;margin-right: 20px;border-radius: 4px;">
    <div class="chiptuningreseller-masthead__logo-container">
        <img style="float:right; padding-right:40px; padding-top:20px; padding-bottom:10px;max-width:300px;" class="chiptuningreseller-masthead__logo" src="<?php echo esc_url( plugins_url( '../../public/assets/chiptuningreseller-logo-black.png', __FILE__ ) ); ?>" alt="ChiptuningReseller"/>
        <h2 style="position:absolute;right:60px;padding-top:25px;"> <?php echo CTR_VERSION; ?></h2>
    </div>
    <?php if(TESTMODE) { ?>
        <h3 class="msg-warning" style="float:right;padding-top:10px;padding-right:15px;">Localhost testmode activated - connected to staging server!</h3>
    <?php } ?>
    Here you can edit your custom templates. If you know some HTML and a little PHP you can make beautiful looking plugin pages that attracts visitors.<br/>
    We use the <strong>Blade template</strong> engine to show data processed by the plugin.<br/><strong>Only edit these template files if you know what you're doing!</strong><br/><br/><br/>
    <div id="templateside" style="padding-left:5px; width:20%; margin-right:1em;">

        <h2 id="plugin-files-label"><?php _e('Template Files'); ?></h2>
        <?php
        $plugin_editable_files = $catalogData['template_files'];
        ?>
        <ul >
            <li  tabindex="-1" aria-expanded="true" aria-level="1" aria-posinset="1" aria-setsize="1">
                <ul role="group">
                    <?php $oldPath = ''; foreach ($plugin_editable_files as &$editFile) { 
                        if($editFile['dir'] == 'custom_templates') {
                            $fileDir = '';
                        } else {
                            $fileDir =  $editFile['dir'] . '/';
                        }
                        if($oldPath !== $editFile['dir']) { 
                            echo '<strong>'.$editFile['dir'].'</strong>'; $oldPath = $editFile['dir'];
                         }
                        ?>
                        <li role="none" class="">
                            <a role="treeitem" tabindex="-1" href="<?php echo admin_url('admin.php?page=__chiptuningreseller&tab=fourth&edit_file=' . $fileDir . basename($editFile['file'])); ?>" aria-level="2" aria-setsize="1" aria-posinset="11">
                                <?php echo basename($editFile['file']); ?></a>
                        </li>
                    <?php } ?>
                </ul>
            </li>
        </ul>
    </div>
    <div style="width:75%">
        <div>
            <div style="width:100%;">
                <textarea id="fancy-textarea" name="file_update"><?php echo esc_textarea($content); ?></textarea>
            </div>
            <input type="hidden" name="file_name" value="<?php echo $loadedFile; ?>">
            <input type="hidden" name="form_type" value="template_file" />
            <input type="hidden" name="update_settings" value="1">
        </form>
    </div>
    <div class="pull-left"><?php submit_button("Save"); ?></div>
    <div class="pull-right"><a id="resetFile" data-filename="<?php echo $loadedFile; ?>" class="button">Or RESET this template (warning, changes to this file will be undone!)</a></div>
    <br/><br/><div class="clearfix"></div>
    <p align="center">Do you need help or some examples? Please refer to our <a href="http://docs.chiptuningreseller.com/wp-plugin/#custom-templates" target="_blank">extensive documentation</a> for more information.</p>
    </div>
    
    </div>
</div>
<?php } ?>
<script>
    jQuery(document).ready(function($) {
        <?php if(isset($file_content_type)) { ?>wp.codeEditor.initialize($('#fancy-textarea'),{'mode': '<?php echo $file_content_type; ?>'}); <?php } ?>
        $( "#resetFile" ).click(function() {
            var $this = $(this);
            var file_name = $(this).data('filename');
            var confTrashCache = confirm("Are you sure? \rThe template will be reset to it\'s default settings.");
            if (confTrashCache == true) {
                jQuery.post(ajaxurl, {'action': 'reset_template_file', 'file_name': file_name}, function(response) {
                    alert(response);
                    location.reload();
                });    
            } else {
                txt = "Nothing deleted";
            }
            
        });

        $( "#copyTemplates" ).click(function() {
            var confTrashCache = confirm("Default templates will be copied so you can edit them");
            if (confTrashCache == true) {
                jQuery.post(ajaxurl, {'action': 'copy_templates'}, function(response) {
                    alert(response);
                    location.reload();
                });    
            } else {
                txt = "Nothing done";
            }
        });
    });
</script>