<?php

/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @link              https://www.chiptuningreseller.com
 * @since             3.0.3
 * @package           Ctr
 *
 * @wordpress-plugin
 * Plugin Name:       ChiptuningReseller
 * Plugin URI:        https://www.chiptuningreseller.com
 * Description:       Chiptuning Information on your website with performance information and media.
 * Version:           5.0.0.4
 * Author:            Chiptuning Reseller
 * Author URI:        https://www.chiptuningreseller.com
 * License:           May not be copied and/or distributed without the express notice of ChiptuningReseller
 * License URI:       https://en.wikipedia.org/wiki/Proprietary_software
 * Text Domain:       ctr
 * Domain Path:       /languages
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

/** Require the Plugin Update Checker from Yhanis  */
require 'plugin-update-checker/plugin-update-checker.php';
/*** Update Checker Settings **/
$updateChecker = Puc_v4_Factory::buildUpdateChecker(
	'https://chiptuningreseller.com/plugin_update/v5/update.json',
	__FILE__,
	'chiptuningreseller'
);


/**
 * Currently plugin version.
 * Start at version 3.0.0 and use SemVer - https://semver.org
 * Rename this for your plugin and update it as you release new versions.
 */
define( 'CTR_VERSION', '5.0.0.4' );
define( 'CTR_PLUGIN_DIR', plugin_dir_path(__FILE__) );


/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-ctr-activator.php
 */
function activate_ctr() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-ctr-activator.php';
	register_rewrites();
	flush_rewrite_rules();
	
	Ctr_Activator::activate();
}

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-ctr-deactivator.php
 */
function deactivate_ctr() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-ctr-deactivator.php';
	Ctr_Deactivator::deactivate();
	flush_rewrite_rules();
}

function register_rewrites() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-ctr-rewrite.php';
	
	$rewriter = new CTR_Rewrite();
	$rewriter->rewrite_urls();
}

/**
 * We need to check if we need to run some updates if our version has been upgraded
 * First, we check the installed version against the current running Plugin version
 * And then, if we updated our data, we set the version in our db to the current running version
 * 
 * @since 3.3.9.6
 */
function update_processing() {
	if (get_site_option( 'ctr_plugin_version' ) == CTR_VERSION) {
        return null;
	} else {
		require 'includes/class-ctr-updator.php';

		$updator = new Ctr_Updator(get_site_option( 'ctr_plugin_version' ), CTR_VERSION);
		$updator->runUpdates();

		/** Update the plugin version in the database also */
		update_site_option( 'ctr_plugin_version' , CTR_VERSION);
	}
}

/**
 * If our plugin has updated the rewrite url, we would like to flush the rewrite rules
 * This must be done after initialisation of the WP rewrite rules to be updated
 * 
 * @since 3.3.9.6
 */
function check_rewrites() {
	if(get_option('ctr_flush_rewrites') == true) {
		global $wp_rewrite;
		$wp_rewrite->flush_rules(false);
		delete_option('ctr_flush_rewrites');
	}
}

add_action('init', 'update_processing', 0);
add_action('init', 'check_rewrites', 999);

register_activation_hook( __FILE__, 'activate_ctr' );
register_deactivation_hook( __FILE__, 'deactivate_ctr' );

/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */
require plugin_dir_path( __FILE__ ) . 'includes/class-ctr.php';


/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since    3.0.0
 */
function run_ctr() {
	$plugin = new Ctr();
	$plugin->run();
}
run_ctr();
