<?php
/**
 * Vehicle Types Class
 *
 * This class communicates with the CTR database
 *
 * @since      3.0.0
 * @package    Ctr
 * @subpackage Ctr/includes
 * @author     M Bos <support@chiptuningreseller.com>
 */
require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-ctr-helpers.php';
require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-ctr-db.php';

class Ctr_Brands {

    private $helper;
    private $use_cache;
    private $database;

    /**
	 * Initialize the class and set its properties.
	 *
	 * @since    3.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct() {
		$this->helper = new Ctr_Helpers();
        $this->database = new Ctr_DB();
        $this->use_cache = $this->database->getSettings()['enable_cache'];

    }
    

    public function getBrands($typeSlug = 'cars', $brandId = null) {
        if (isset($typeSlug)) {
            // Translate the typeslug to our internal naming
            $typeSlug = $this->helper->translate_vehicle_type($typeSlug, 'internal');
            
            $cached = $this->helper->get_cache('brands_' . $typeSlug);
            if(($this->use_cache == 1) && (is_array($cached))) {
                return $cached;
            }

            global $wpdb;
            $catalogData = null;
            $url = API_URL . 'brands?type=' . $typeSlug;
            
            $response = wp_remote_get(
                    $url, array(
                        'body' => '',
                        'timeout' => 30,
                        'headers' => [
                        'Authorization' => 'Bearer ' . $this->database->getApiKey()
                    ]
                )
            );
            ;

            if (!is_wp_error( $response ) && wp_remote_retrieve_response_code($response) == 200) {
               $responseData = json_decode($response['body'], true);
                if(isset($brandId)) {
                    foreach($responseData as $brand) {
                        if($brand['id'] == $brandId) {
                            return $brand;
                        };
                    }
                }
                $this->helper->set_cache('brands_' . $typeSlug, $responseData, 'ctr', 43300); // Save our brands for at least 12 hours
                return $responseData;
            } elseif(wp_remote_retrieve_response_code($response) == 429) {
                echo "<!-- <small>[CTR] Something went wrong retrieving the brands: too many requests</small>-->";
                return [];
            }
            echo "<small>[CTR] Something went wrong retrieving the Brands data</small>";
        }
    }

    /**
     * Get one brand by it's id
     */
    public function getById($brandId, $source = NULL)
    {
        $cacheCode = $source . '_brandbyid_' . base64_encode($brandId);
        $engineCache = $this->helper->get_cache($cacheCode);
        if (false !== $engineCache && $this->use_cache == 1 && !empty($engineCache)) {
            return $engineCache;
        }
        $source = null != $source ? '?source=' . $source : '';
        global $wpdb;
        $catalogData = null;
        $catalogData = $wpdb->get_row("SELECT * FROM {$wpdb->prefix}chiptuningreseller WHERE id=1", ARRAY_A);
        $url = API_URL . 'brands/' . $brandId . $source;
        
        $response = wp_remote_get(
            $url,
            array(
                'body' => '',
                'timeout' => 30,
                'headers' => [
                    'Authorization' => 'Bearer ' . $this->database->getApiKey()
                ]
            )
        );

        if (is_wp_error($response)) {
            $error_message = $response->get_error_message();
            echo "Something went wrong: $error_message";
        } else {
            $responseData = json_decode($response['body'], true);
            $this->helper->set_cache($cacheCode, $responseData, 'ctr', 73049); // Save our brand for at least 1 month
            return $responseData;
        }
    }

    public function getTypes($id) {

    }

}