<?php
/**
 * API Search class
 * We will use the powerful ChiptuningReseller Search API
 *
 * This class communicates with the CTR database
 *
 * @since      3.0.0
 * @package    Ctr
 * @subpackage Ctr/includes
 * @author     M Bos <support@chiptuningreseller.com>
 */
require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-ctr-helpers.php';
require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-ctr-db.php';

class Ctr_Search {

    private $helper;
    private $use_cache;

    /**
	 * Initialize the class and set its properties.
	 *
	 * @since    3.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct() {

		$this->helper = new Ctr_Helpers();
		$this->database = new Ctr_DB();
        $this->use_cache = $this->database->getSettings()['enable_cache'];
    }
    

    /**
     * Get data by Engine Tags (like read_method, bore_x_stroke etc etc)
     */
    public function getByEngineTag($key, $search_relations, $value, $only_types = null) {
        if (isset($only_types)) {
            // Translate the typeslug to our internal naming
            $vehicle_type = $this->helper->translate_vehicle_type($only_types, 'internal');
        }
        $url = API_URL . 'search/by-engine-tags?key=' . $key . '&value='. $value . '&search_relations=' . $search_relations;
        $cached = $this->helper->get_cache('search_by_engine_tags' . $key . '_' . $value . '_' . $search_relations . '_' . $only_types);
        if(($this->use_cache == 1) && (is_array($cached))) {
            return $cached;
        }

        global $wpdb;
        $catalogData = null;
        
        if(null != $value) {
            $url .= '&value=' . $value;
        }
        
        $response = wp_remote_get(
                $url, array(
                    'body' => '',
                    'timeout' => 30,
                    'headers' => [
                    'Authorization' => 'Bearer ' . $this->database->getApiKey()
                ]
            )
        );

        if (is_wp_error( $response )) {
           $error_message = $response->get_error_message();
           //echo "Something went wrong: $error_message";
        } else {
            $responseData = json_decode($response['body'], true);
            $this->helper->set_cache('search_by_engine_tags' . $key . '_' . $value . '_' . $search_relations . '_' . $only_types, 'ctr', 43300); // Save our data for at least 12 hours
            return $responseData;
        }
    }

    public function searchAllData($searchTerm) {
        if (isset($searchTerm)) {

            global $wpdb;
            $catalogData = null;
            $url = API_ES_URL . 'vehicles/';
            
            $response = wp_remote_post(
                    $url, array(
                        'body' => json_encode([
                            'size' => 30,
                            "from" => 0,
                            "search_text" => $searchTerm,
                            "sort" => "id",
                            "sort_order" => "DESC"
                        ]),
                        'timeout' => 30,
                        'headers' => [
                        'Authorization' => 'Bearer ' . $this->database->getApiKey()
                    ]
                )
            );

            if (is_wp_error( $response )) {
               $error_message = $response->get_error_message();
               echo "Something went wrong: $error_message";
            } elseif($response['response']['code'] !== 200) {
                $error_message = $response['response']['status'];
                echo "Something went wrong: $error_message";
            } else {
                echo $response['body']; exit;
            }
        }
    }

    public function getTypes($id) {

    }

}