<?php
/**
 * Vehicle Builds Class
 *
 * This class communicates with the CTR database and retrieves the SERIES
 *
 * @since      3.0.0
 * @package    Ctr
 * @subpackage Ctr/includes
 * @author     M Bos <support@chiptuningreseller.com>
 */
require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-ctr-helpers.php';
require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-ctr-db.php';

class Ctr_SelectorApi {

    private $helper;
    private $vehicle_type;
    private $use_cache;
    private $base_dir;

    /**
	 * Initialize the class and set its properties.
	 *
	 * @since    3.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct($vehicle_type = 'cars') {
		$this->helper = new Ctr_Helpers();
        $this->database = new Ctr_DB();
        $this->base_dir = wp_upload_dir()['basedir'] . '/ctr/';
    }
    

   
    public function getSelectorDataPath() {
        $pluginPath = wp_upload_dir()['baseurl'];
        return $pluginPath . '/ctr/vdata.json';
    }

    /***
    *
    * Get a list with all vehicle data
    *
    ***/
    public function getSelectorData() {
            $jsonFile = $this->base_dir . 'vdata.json';
        
            if((file_exists($jsonFile)) && (filesize($jsonFile) > 1024)) {
                return file_get_contents($jsonFile);
            }
            
            global $wpdb;
            $catalogData = null;
            $catalogData = $wpdb->get_row("SELECT * FROM {$wpdb->prefix}chiptuningreseller WHERE id=1", ARRAY_A);
            $url = API_URL . 'selectordata';
            
            $response = wp_remote_get(
                    $url, array(
                        'body' => '',
                        'timeout' => 30,
                        'headers' => [
                        'Authorization' => 'Bearer ' . $this->database->getApiKey()
                    ]
                )
            );
            
            if (!is_wp_error( $response ) && wp_remote_retrieve_response_code($response) == 200) {
                file_put_contents($jsonFile, $response['body']);
               return $response['body'];
            } elseif(wp_remote_retrieve_response_code($response) == 429) {
                echo "<!-- <small>[CTR] Something went wrong retrieving the selector data: too many requests</small>-->";
                return [];
            }
            echo "<small>[CTR] Something went wrong retrieving the selector data</small>";
        }

}