<?php
/**
 * Vehicle Series Class
 *
 * This class communicates with the CTR database and retrieves the SERIES
 *
 * @since      3.0.0
 * @package    Ctr
 * @subpackage Ctr/includes
 * @author     M Bos <support@chiptuningreseller.com>
 */
require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-ctr-helpers.php';
require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-ctr-db.php';

class Ctr_Series {

    private $helper;
    private $vehicle_type;
    private $use_cache;

    /**
	 * Initialize the class and set its properties.
	 *
	 * @since    3.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct($vehicle_type = 'cars') {
		$this->helper = new Ctr_Helpers();
        $this->database = new Ctr_DB();
        $this->use_cache = $this->database->getSettings()['enable_cache'];
        $this->vehicle_type = $this->helper->translate_vehicle_type($vehicle_type, 'internal');
    }
    

    public function getSeries($brandId = NULL, $brandSlug = NULL) {
        if (isset($brandId) || isset($brandSlug)) {
            $cacheCode = $this->vehicle_type . '_series_' . base64_encode($brandId . '_' . $brandSlug);
            $serieCache = $this->helper->get_cache($cacheCode);
            
            if(false !== $serieCache && $this->use_cache == 1 && !empty($serieCache)) {
                return $serieCache;
            }
            

            $url = (isset($brandSlug)) ? API_URL . 'series/byslug?type='. $this->vehicle_type .'&brand_slug=' . $brandSlug : API_URL . 'series?brand_id=' . $brandId;
            $response = wp_remote_get(
                    $url, array(
                        'body' => '',
                        'timeout' => 30,
                        'headers' => [
                        'Authorization' => 'Bearer ' . $this->database->getApiKey()
                    ]
                )
            );
            
            if (!is_wp_error( $response ) && wp_remote_retrieve_response_code($response) == 200) {
               $responseData = json_decode($response['body'], true);
               $this->helper->set_cache($cacheCode, $responseData, 'ctr'); // Save indefinite
               return $responseData;
            } elseif(wp_remote_retrieve_response_code($response) == 429) {
                echo "<!-- <small>[CTR] Something went wrong retrieving the series: too many requests</small>-->";
                return [];
            }
            echo "<small>[CTR] Something went wrong retrieving the Series data</small>";
        }
    }

    /**
     * Get one serie by it's id
     */
    public function getById($serieId, $source = NULL)
    {
        $cacheCode = $source . '_seriebyid_' . base64_encode($serieId);
        $engineCache = $this->helper->get_cache($cacheCode);
        if (false !== $engineCache && $this->use_cache == 1 && !empty($engineCache)) {
            return $engineCache;
        }

        $source = null != $source ? '?source=' . $source : '';

        global $wpdb;
        $catalogData = null;
        $catalogData = $wpdb->get_row("SELECT * FROM {$wpdb->prefix}chiptuningreseller WHERE id=1", ARRAY_A);
        $url = API_URL . 'series/' . $serieId;
        
        $response = wp_remote_get(
            $url,
            array(
                'body' => '',
                'timeout' => 30,
                'headers' => [
                    'Authorization' => 'Bearer ' . $this->database->getApiKey()
                ]
            )
        );

        if (is_wp_error($response)) {
            $error_message = $response->get_error_message();
            echo "Something went wrong: $error_message";
        } else {
            $responseData = json_decode($response['body'], true);
            $this->helper->set_cache($cacheCode, $responseData, 'ctr', 73049); // Save our serie for at least 1 month
            return $responseData;
        }
    }

}