<?php
/**
 * Vehicle Stages Class
 *
 * This class communicates with the CTR database and retrieves the SERIES
 *
 * @since      3.0.0
 * @package    Ctr
 * @subpackage Ctr/includes
 * @author     M Bos <support@chiptuningreseller.com>
 */
require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-ctr-helpers.php';
require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-ctr-db.php';

class Ctr_Stages {

    private $helper;
    private $vehicle_type;

    /**
	 * Initialize the class and set its properties.
	 *
	 * @since    3.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct($vehicle_type = 'cars') {
		$this->helper = new Ctr_Helpers();
        $this->database = new Ctr_DB();
        
        $this->vehicle_type = $this->helper->translate_vehicle_type($vehicle_type);
    }
    
    /***
    *
    * Get a list with vehicle stages
    *
    ***/
    public function getStages($engineId = NULL,  $brandSlug = NULL, $serieSlug = NULL, $modelSlug = NULL, $engineSlug = NULL){
        if (isset($engineId) || (isset($modelSlug) && isset($brandSlug) && isset($serieSlug) && isset($engineSlug))) {
            $url = isset($engineId) ? API_URL . 'stages/by-engine-id/' . $engineId : API_SEARCH_URL . '?type='. $this->vehicle_type .'&brand_slug='. $brandSlug .'&serie_slug='. $serieSlug .'&model_slug=' . $modelSlug . '&engine_slug=' . $engineSlug . '&with=brand,serie,model,engine';
            
            $cache_code = $this->vehicle_type . '_stages_' . base64_encode($modelSlug . '_' . $engineId);
            $stageCache = $this->helper->get_cache($cache_code);
            if(false !== $stageCache && !empty($stageCache)) {
                return $stageCache;
            }
            global $wpdb;
            $catalogData = null;
            $catalogData = $wpdb->get_row("SELECT * FROM {$wpdb->prefix}chiptuningreseller WHERE id=1", ARRAY_A);
            $response = wp_remote_get(
                    $url, array(
                        'body' => '',
                        'timeout' => 30,
                        'headers' => [
                        'Authorization' => 'Bearer ' . $this->database->getApiKey()
                    ]
                )
            );
            if (!is_wp_error( $response ) && wp_remote_retrieve_response_code($response) == 200) {
                $responseData = json_decode($response['body'], true);
                $this->helper->set_cache($cache_code, $responseData, 'ctr', 3600); // Save our models for at least 1 hour
                return $responseData;
            } elseif(wp_remote_retrieve_response_code($response) == 429) {
                echo "<!-- <small>[CTR] Something went wrong retrieving the stages: too many requests</small>-->";
                return [];
            }
            echo "<small>[CTR] Something went wrong retrieving the stages data</small>";
        }
    }

}