<?php

/**
 * Functionality helpers
 *
 * @link       https://www.chiptuningreseller.com
 * @since      3.0.0
 *
 * @package    Ctr
 * @subpackage Ctr/includes
 */

/**
 * Functionality helpers
 *
 * This class Adds helpers
 *
 * @since      3.0.0
 * @package    Ctr
 * @subpackage Ctr/includes
 * @author     M Bos <support@chiptuningreseller.com>
 */
class Ctr_Helpers {
    private $tagline;
    private $connection_valid;
    
    /**
    * Show a notice of $type with $message
    * @param string $type
    * @param $message
    */
    public function show_notice( $type = "success", $message, $topnotice = false) {
        if(!$topnotice) {
        ?>
            <div class="notice notice-<?php echo $type; ?> is-dismissible">
                <p><?php echo $message; ?></p>
            </div>
        <?php
        } else {
            ?>
            <div style="position:fixed; bottom:0px; height: auto; width:100%; z-index:99999; background-color:rgba(0,0,0,0.5); color:#fff; padding:10px;" class="notice notice-<?php echo $type; ?> is-dismissible">
                <p>Hello there. ChiptuningReseller here. <br/><?php echo $message; ?></p>
            </div>
            <?php
        }
    }


    /****
    *
    * Check if the API connection is valid
    *
    *
    ***/
    public function check_api_connection() {
        if(null != $this->connection_valid) {
            return $this->connection_valid;
        }

        // if($this->get_cache('ctr_validated_user')) {
        //     $this->connection_valid = $this->get_cache('ctr_validated_user');
        //     return $this->connection_valid;
        // }

        global $wpdb;
        $catalogData = null;
        $catalogData = $wpdb->get_row("SELECT * FROM {$wpdb->prefix}chiptuningreseller WHERE id=1", ARRAY_A);
        $url = BASEURL .  'check';
        
        $response = wp_remote_get(
                $url, array(
                    'body' => '',
                    'timeout' => 30,
                    'headers' => [
                    'Authorization' => 'Bearer ' . $catalogData['api_key']
                ]
            )
        );
        if (is_wp_error( $response )) {
           $error_message = $response->get_error_message();
           echo "CTR: Something went wrong: $error_message";
           return 'error_api';           
        } else {
           $responseData = json_decode($response['body'], true);
           if($responseData !== 'error' && (isset($responseData['currentUser']))) {
                $this->connection_valid = $responseData['currentUser'];
                $this->set_cache('ctr_validated_user', $responseData['currentUser'], 'ctr', 7200);

                return $responseData['currentUser'];
           } elseif($responseData === 'no_subscription') {
               // Clear out all cache
               $wpdb->query("DELETE FROM {$wpdb->prefix}options WHERE option_name LIKE ('%_ctr_%');");
               return 'banned';
           }
           return false;
        }
    }

    /**
     * Get a list with currently supported languages
     */
    public function get_languages() {
        $options_lang = array(
            ['id' =>'auto' , 'name' => "Automatic"],
            ['id' =>'da_dk' , 'name' => "Danish (Dansk)"],
            ['id' =>'de_de' , 'name' => "Deutsch (Deutschland)"],
            ['id' =>'en_us' , 'name' => "English (United States)"],
            ['id' =>'es_es' , 'name' => "Español (España)"],
            ['id' =>'fr_fr' , 'name' => "Français (France)"],
            ['id' =>'it_it' , 'name' => "Italiano (Italia)"],
            ['id' =>'nl_nl' , 'name' => "Nederlands"],
            ['id' =>'no_no' , 'name' => "Norsk (Nynorsk)"],
            ['id' =>'nb_no' , 'name' => "Norsk (Bokmål )"],            
            ['id' =>'pl_pl' , 'name' => "Polish"],
            ['id' =>'pt_pt' , 'name' => "Português (Brasil)"],
            ['id' =>'sv_se' , 'name' => "Swedish"],
            ['id' =>'uk_uk' , 'name' => "Ukranian"],
            ['id' =>'ru_ru' , 'name' => "русский (Россия)" ]
            );
        return $options_lang;
    }


    /**
     * Delete a cached item from the transients
     */
    public function delete_cache($key, $group = 'ctr')
    {
        return delete_transient( get_current_blog_id() . '_' . $group . '_' . $key );
    }

    /**
     * Check if data already exists in cache and if so, return it.
     */
    public function get_cache($key, $group = 'ctr')
    {
        return get_transient( get_current_blog_id() . '_' . $group . '_' . $key );
    }

    /**
     * Set cached data
     */
    public function set_cache($key, $data, $group = 'ctr', $expire = 0)
    {
        //return wp_cache_set($key, $data, $group, $expire);
        return set_transient( get_current_blog_id() . '_' . $group . '_' . $key, $data, $expire );
    }

    /**
     * Clean a string for HTML output
     */
    public function cleanString($string) {
        $search = ['<', '>', '"'];
        $replace = ['', '', ''];
        $string = str_replace($search, $replace, $string);
        return $string;
    }

    /**
     * Check if something exists in an array by using strpos
     */
    public function strposa($haystack, $needles = array(), $offset=0) {
        $chr = array();
        foreach($needles as $needle) {
                $res = stripos($haystack, $needle, $offset);
                if ($res !== false) $chr[$needle] = $res;
        }
        if(empty($chr)) return false;
        return min($chr);
}

     /***
    *
    * Translate the vehicle URL to the official slug URL
    * If the $lang param is set, the translated vehicle type will be returned according to the language
    *
    ***/
    public function translate_vehicle_type($search_type, $to_lang = null) {
        
        $search_type = strtolower($search_type);
        global $wpdb;
        $data = $wpdb->get_row("SELECT display_lang FROM {$wpdb->prefix}chiptuningreseller WHERE id=1 LIMIT 1", ARRAY_A);

        $lang = null != get_locale() ? strtolower(get_locale()) : 'en_us';
        
        if(((isset($data['display_lang'])) && $data['display_lang'] !== 'auto') && $to_lang != 'internal') {
            $lang = $data['display_lang'];
        }
        if($to_lang == 'internal') {
            $lang = 'en_us';
        }

        $types['cars'] = [
            "nl_nl"    => "autos",
            "de_de"    => "autos",
            "en_us"    => "cars",
            "es_es"    => "autos",
            "fr_fr"    => "voitures",
            "it_it"    => "automobili",
            "pt_pt"    => "carros",
            "no_no"    => "biler",
            "nb_no"    => "bil",
            "da_dk"     => "biler",
            "pl_pl"     => "samochody",
            "ru_ru"     => "автомобилей",
            "sv_se"     => "bilar",
        ];

        $types['bikesquad'] = [
            "nl_nl"    => "motoren-en-quads",
            "de_de"    => "fahrrader-und-quads",
            "en_us"    => "bikes-and-quads",
            "es_es"    => "bicicletas-y-quads",
            "fr_fr"    => "motos-et-quads",
            "it_it"    => "biciclette-e-quad",
            "pt_pt"    => "bicicletas-e-quads",
            "nb_no"    => "mc-og-atv",
            "no_no"    => "mc-og-atv",
            "da_dk"    => "motorer-og-quads",
            "pl_pl"    => "motocykle-i-quady",
            "ru_ru"    => "мотоциклы-и-квадроциклы",
            "sv_se"     => "motorcyklar-och-fyrhjulingar",
        ];

        $types['motorboats'] = [
            "nl_nl"    => "boten",
            "de_de"    => "motorboote",
            "en_us"    => "boats",
            "es_es"    => "lanchas-a-motor",
            "fr_fr"    => "bateaux-a-moteur",
            "it_it"    => "motoscafi",
            "pt_pt"    => "lanchas",
            "no_no"    => "bater",
            "nb_no"    => "bat",
            "da_dk"    => "motorbade",
            "pl_pl"    => "lodzie-motorowe",
            "ru_ru"    => "моторные-лодки",
            "sv_se"    => "batar",
        ];

        $types['jet-skis'] = [
            "nl_nl"    => "jet-skis",
            "de_de"    => "jet-ski",
            "en_us"    => "jet-skis",
            "es_es"    => "jet-skis",
            "fr_fr"    => "jet-skis",
            "it_it"    => "moto-dacqua",
            "pt_pt"    => "jet-skis",
            "no_no"    => "vannscooter",
            "nb_no"    => "vannscooter",
            "da_dk"    => "jet-ski",
            "pl_pl"    => "skutery-wodne",
            "ru_ru"    => "водные-мотоциклы",
            "sv_se"    => "vattenskoter",
        ];

        $types['tractors'] = [
            "nl_nl"    => "tractoren",
            "de_de"    => "traktoren",
            "en_us"    => "tractors",
            "es_es"    => "tractores",
            "fr_fr"    => "tracteurs",
            "it_it"    => "trattori",
            "pt_pt"    => "tratores",
            "no_no"    => "traktorer",
            "nb_no"    => "traktor",
            "da_dk"    => "traktorer",
            "pl_pl"    => "ciagniki",
            "ru_ru"    => "тракторы",
            "sv_se"    => "traktorer"
        ];

        $types['trucks'] = [
            "nl_nl"    => "trucks",
            "de_de"    => "lastwagen",
            "en_us"    => "trucks",
            "es_es"    => "camiones",
            "fr_fr"    => "camions",
            "it_it"    => "camion",
            "pt_pt"    => "camiones",
            "no_no"    => "lastebiler",
            "nb_no"    => "lastebil",
            "da_dk"    => "lastbiler",
            "pl_pl"    => "ciezarowki",
            "ru_ru"    => "грузовые автомобили",
            "sv_se"    => "lastbilar",
        ];

        $types['snowmobiles'] = [
            "nl_nl"    => "sneeuwscooter",
            "de_de"    => "schneemobil",
            "en_us"    => "snowmobile",
            "es_es"    => "motonieve",
            "fr_fr"    => "motoneige",
            "it_it"    => "gatto-delle-nevi",
            "pt_pt"    => "moto-de-neve",
            "no_no"    => "snoscooter",
            "nb_no"    => "snoscooter",
            "da_dk"    => "snescootere",
            "pl_pl"    => "skutery-sniezne",
            "ru_ru"    => "снегоходы",
            "sv_se"    => "snoskotrar",
        ];

        
        if($lang) {
            if($to_lang == 'internal') {
                $internal_type = $this->recursiveFindParentKey($types, $search_type);
                if(null !== $internal_type) {
                    return $internal_type;
                }
                return $search_type;
            }
            foreach($types as $key => $type) {
                if($search_type == $key) {
                    return isset($types[$key][$lang]) ? $types[$key][$lang] : $types[$key]['en_us'];
                }
            }
        } else {
            foreach($types as $key => $type) {
                if(in_array($search_type, $type)) {
                    return $key;
                }
            }
        }
        return $search_type;
            
    }

    /***
    *
    * Translate the vehicle URL to the official slug URL
    * If the $lang param is set, the translated vehicle type will be returned according to the language
    *
    ***/
    public function translate_fuel_type($search_type, $lang = null) {
        $search_type = strtolower($search_type);
        if($lang == 'auto') {
            $lang = null != get_locale() ? strtolower(get_locale()) : 'en_us';
        }
        $data = '';
        
        $strings = [
        "lbl_fuel_general"    => array(
            "nl_nl"               => "benzine",
            "de_de"               => "Benzin",
            "en_us"               => "gasoline",
            "es_es"               => "gasolina",
            "fr_fr"              => "essence",
            "it_it"               => "benzina",
            "pt_pt"               => "gasolina",
            "ru_ru"               => "бензин",
            "no_no"               => "bensin",
            "nb_no"             => "bensin",
            "sv_se"             => "bensin"
        ),
        "lbl_fuel_gasoline"    => array(
            "nl_nl"               => "benzine",
            "de_de"               => "Benzin",
            "en_us"               => "gasoline",
            "es_es"               => "gasolina",
            "fr_fr"              => "essence",
            "it_it"               => "benzina",
            "pt_pt"               => "gasolina",
            "ru_ru"               => "бензин",
            "no_no"               => "bensin",
            "nb_no"             => "bensin",
            "sv_se"             => "bensin",
        ),
        "lbl_fuel_diesel"    => array(
            "nl_nl"               => "diesel",
            "de_de"               => "Diesel",
            "en_us"               => "diesel",
            "es_es"               => "diesel",
            "fr_fr"              => "diesel",
            "it_it"               => "diesel",
            "pt_pt"               => "diesel",
            "ru_ru"               => "дизель",
            "no_no"               => "diesel",
            "nb_no"             => "diesel",
            "sv_se"             => "diesel",
        ),
        "lbl_fuel_hybrid"    => array(
            "nl_nl"               => "hybride",
            "de_de"               => "Hybrid",
            "en_us"               => "hybrid",
            "es_es"               => "híbrido",
            "fr_fr"              => "hybride",
            "it_it"               => "ibrido",
            "pt_pt"               => "híbrido",
            "ru_ru"               => "гибрид",
            "no_no"               => "hybrid",
            "nb_no"             => "hybrid",
            "sv_se"             => "hybrid"
        )
        ];

        if($lang) {
            foreach($strings as $key => $type) {
                if($search_type == $key) {
                    $data = isset($strings[$key][$lang]) ? $strings[$key][$lang] : $strings[$key]['en_us'];
                }
            }
        } elseif(!isset($data)) {  
            foreach($strings as $key => $type) {
                if(in_array($search_type, $type)) {
                    $data = $key;
                }
            }
        }

        return $data;
    }

    public function minimizeCSS($css){
        $css = preg_replace('/\/\*((?!\*\/).)*\*\//', '', $css); // negative look ahead
        $css = preg_replace('/\s{2,}/', ' ', $css);
        $css = preg_replace('/\s*([:;{}])\s*/', '$1', $css);
        $css = preg_replace('/;}/', '}', $css);
        return $css;
    }

    public function minimizeJS($js) {
        return preg_replace(array("/\s+\n/","/\n\s+/","/ +/"),array("\n","\n "," "), $js);
    }

    public function getTestmode() {
        return TESTMODE;
    }

    public function calculatePercentageIncrease($numberOne, $numberTwo) {
        if(intval($numberOne) > 0 && intval($numberTwo) > 0) {
            $increase = round($numberTwo - $numberOne) / $numberOne * 100;
            return round($increase);
        }
        return 0;
    }

    public function rgbaConverter($color) {
        $default = 'rgb(0,0,0)';
 
        //Return default if no color provided
        if(empty($color)) {
            return $default; 
        }
        
        //Sanitize $color if "#" is provided 
        if ($color[0] == '#' ) {
            $color = substr( $color, 1 );
        }

        //Check if color has 6 or 3 characters and get values
        if (stripos($color, 'rgba') !== false ) {
            return $color;
        }
        elseif (strlen($color) == 6) {
                $hex = array( $color[0] . $color[1], $color[2] . $color[3], $color[4] . $color[5] );
        } elseif ( strlen( $color ) == 3 ) {
                $hex = array( $color[0] . $color[0], $color[1] . $color[1], $color[2] . $color[2] );
        } else {
                return $default;
        }
        //Convert hexadec to rgb
        $rgb =  array_map('hexdec', $hex);

        //Check if opacity is set(rgba or rgb)
        if(isset($opacity)) {
            if(abs($opacity) > 1)
                $opacity = 1.0;
            $output = 'rgba('.implode(",",$rgb).','.$opacity.')';
        } else {
            $output = 'rgb('.implode(",",$rgb).')';
        }

        //Return rgb(a) color string
        return $output;
    }



    /** Get the URL of the current request **/
    public function get_url()
    {
        global $wp;
        $current_url = home_url(add_query_arg(array(), $wp->request));
        return $current_url;
    }

    public function getAssetsUrl() {
        return content_url('uploads/ctr/assets/');
    }

    /** Run a shortcode - this can be used in the templator blade engine to include shortcodes easily */
    public static function shortcode($name, $params = null) {
        $parameterData = '';
        if(null != $params) {            
            foreach($params as $key => $val) {
                $parameterData .= $key . '="' . $val . '"';
            }
        }
        return do_shortcode("[$name $parameterData]");
    }

    public function array_key_search_r($haystack, $needle, $returnKey = false) {
        $iterator  = new RecursiveArrayIterator($haystack);
        $recursive = new RecursiveIteratorIterator(
            $iterator,
            RecursiveIteratorIterator::SELF_FIRST
        );
        foreach ($recursive as $key => $value) {
            if ($key === $needle) {
                return $returnKey ? $key : $value;
            }
        }
    }


    /**
     * We want to find the key of the parent array recursively
     * For example, we have the search string 'bil' which is Norsk for Cars, then we want they key 'cars' to be returned so we can use this in the API
     */
    public function recursiveFindParentKey(array $datas, $needle) {
        foreach ($datas as $key => $data) {
            foreach ($data as $inx => $stx) {
                if ($needle == $stx) {
                    return $key;
                }
                if ((is_array($stx)) && (in_array($needle, $stx))) {
                    return $inx;
                }
            }
        }
        return null;
    }

    /**
     * Get the domain the Wordpress site is running on. 
     * We will also remove the trailing slash if present (rtrim)
     */
    public function getDomain($forMedia = false) {
        $sURL    = network_home_url(); // WordPress function - returns the full home url including possible language subfolders
        
        if($forMedia) { 
            /*For media items we want to return the full path (including subfolder 
              where data is stored) if needed but WITHOUT subfolders for example /nl /de if WPML is used */
            $sURL    = network_site_url();
            return rtrim($sURL, '/');
        }

        $sReturn =  rtrim($sURL, '/');
        return $sReturn;
    }

    /**
     * Check if we need to add a trailing slash to all internal URLS.
     * This needs to be done sometimes (or in most default cases) to prevent 301's
     * 
     */
    public function getTrailingSlash() {
        $structure = get_option( 'permalink_structure' );
        if(strlen($structure) > 0) {
            if(strcmp($structure[-1], "/") === 0) { // Get the last character in the permalink_structure option
                return "/";
            }
        }
        return "";
    }


    /**
     * Delete a directory and all its files in it
     */
    public function deleteDirectory($dir) {
        $it = new RecursiveDirectoryIterator($dir, RecursiveDirectoryIterator::SKIP_DOTS);
        $files = new RecursiveIteratorIterator($it, RecursiveIteratorIterator::CHILD_FIRST);
        try {
        foreach($files as $file) {
                if ($file->isDir()){
                    rmdir($file->getRealPath());
                } else {
                    unlink($file->getRealPath());
                }
            }
            rmdir($dir);
            return true;
        } catch (Exception $e) { 
            return false;
        }
    }

}
