<?php

/**
 * AJAX functionalities
 *
 * This class only handles the AJAX Requests for the dropdown Selector
 *
 * @since      4.0.1.5
 * @package    Ctr
 * @subpackage Ctr/includes
 * @author     M Bos <support@chiptuningreseller.com>
 */
require_once plugin_dir_path(dirname(__DIR__)) . 'includes/class-ctr-db.php';
require_once plugin_dir_path(dirname(__DIR__)) . 'includes/class-ctr-helpers.php';
require_once plugin_dir_path(dirname(__DIR__)) . 'includes/class-ctr-rewrite.php';
require_once plugin_dir_path(dirname(__DIR__)) . 'includes/class-ctr-templator.php';
require_once plugin_dir_path(dirname(__DIR__)) . 'includes/class-ctr-api-vehicle-types.php';
require_once plugin_dir_path(dirname(__DIR__)) . 'includes/class-ctr-api-brands.php';
require_once plugin_dir_path(dirname(__DIR__)) . 'includes/class-ctr-api-series.php';
require_once plugin_dir_path(dirname(__DIR__)) . 'includes/class-ctr-api-models.php';
require_once plugin_dir_path(dirname(__DIR__)) . 'includes/class-ctr-api-engines.php';
require_once plugin_dir_path(dirname(__DIR__)) . 'includes/class-ctr-api-stages.php';
require_once plugin_dir_path(dirname(__DIR__)) . 'includes/class-ctr-api-search.php';
require_once plugin_dir_path(dirname(__DIR__)) . 'public/includes/class-ctr-stagedata.php';

class Ctr_Ajax
{
	private $helpers;
	private $settings;

	public function __construct()
	{
        $ajaxRequest = get_query_var( 'ajax' );
        
		$this->helpers = new Ctr_Helpers();
		$this->rewrite_class = new CTR_Rewrite();
		$this->base_dir = wp_upload_dir()['basedir'] . '/ctr/';

		$CtrDB = new Ctr_DB();
		$this->settings = $CtrDB->getSettings();
        $this->handleAjax();
	}

    public function handleAjax()
	{
		$data = $this->rewrite_class->get_query_vars();

		// Get the engine by its id and return the redirection URL so the dropdown can forward the customer to the engine page
		if (isset($data['vehicle_engine_id'])) {
			$engineData = new Ctr_Engines($data['vehicle_type']);
			$engineData = isset($data['vehicle_engine_id']) ? $engineData->getById($data['vehicle_engine_id'], 'brand,serie,model') : '';
			if (isset($engineData) && (is_array($engineData))) {
				$vehicle_type = $this->helpers->translate_vehicle_type($engineData['brand']['type'], 'auto');
				$ROOT_URL = rtrim(get_home_url(), '/') . '/' . $this->settings['start_url'];

				$stageData['url'] = $ROOT_URL . '/' . $vehicle_type . '/' . $engineData['brand']['slug'] . '/' . $engineData['serie']['slug'] . '/' . $engineData['model']['slug'] . '/' . $engineData['slug'] . '/' . $engineData['id'];
			}
			wp_send_json($stageData);
			exit;
		}
		if (isset($data['vehicle_model_id'])) {
			$apiEngines = new Ctr_Engines($data['vehicle_model_id']);
			$engineData = $apiEngines->getEngines($data['vehicle_model_id']);
			wp_send_json($engineData);
			exit;
		}
		if (isset($data['vehicle_serie_id'])) {
			$apiModels = new Ctr_Models($data['vehicle_type']);
			$modelData = $apiModels->getModels($data['vehicle_serie_id']);
			wp_send_json($modelData);
			exit;
		} elseif (isset($data['vehicle_brand_id'])) {
			$apiSeries = new Ctr_Series($data['vehicle_type']);
			$serieData = $apiSeries->getSeries($data['vehicle_brand_id']);
			wp_send_json($serieData);
			exit;
		} elseif (isset($data['vehicle_type'])) {
			$apiBrands = new Ctr_Brands();
			$data['brands'] = $apiBrands->getBrands($data['vehicle_type']);
			wp_send_json($data['brands']);
			exit;
		} else {
			$apiVehicleTypes = new Ctr_VehicleTypes();
			$data['vehicle_types'] = $apiVehicleTypes->getAllTypes();
			wp_send_json($data['vehicle_types']);
			exit;
		}
	}
}

$ajaxHandler = new Ctr_Ajax();