<?php

/**
 * Display functionalities
 *
 * This class display functions
 *
 * @since      3.0.0
 * @package    Ctr
 * @subpackage Ctr/includes
 * @author     M Bos <support@chiptuningreseller.com>
 */
require_once plugin_dir_path(dirname(__DIR__)) . 'includes/class-ctr-db.php';
require_once plugin_dir_path(dirname(__DIR__)) . 'includes/class-ctr-helpers.php';
require_once plugin_dir_path(dirname(__DIR__)) . 'includes/class-ctr-seo.php';
require_once plugin_dir_path(dirname(__DIR__)) . 'includes/class-ctr-rewrite.php';
require_once plugin_dir_path(dirname(__DIR__)) . 'includes/class-ctr-media.php';
require_once plugin_dir_path(dirname(__DIR__)) . 'includes/class-ctr-templator.php';
require_once plugin_dir_path(dirname(__DIR__)) . 'includes/class-ctr-api-vehicle-types.php';
require_once plugin_dir_path(dirname(__DIR__)) . 'includes/class-ctr-api-brands.php';
require_once plugin_dir_path(dirname(__DIR__)) . 'includes/class-ctr-api-series.php';
require_once plugin_dir_path(dirname(__DIR__)) . 'includes/class-ctr-api-models.php';
require_once plugin_dir_path(dirname(__DIR__)) . 'includes/class-ctr-api-engines.php';
require_once plugin_dir_path(dirname(__DIR__)) . 'includes/class-ctr-api-stages.php';
require_once plugin_dir_path(dirname(__DIR__)) . 'includes/class-ctr-api-search.php';
require_once plugin_dir_path(dirname(__DIR__)) . 'public/includes/class-ctr-stagedata.php';

class Ctr_Display
{
	private $seo;
	private $helpers;
	private $ctrTemplator;
	private $settings;
	private $base_dir;

	public function __construct()
	{
		$this->helpers = new Ctr_Helpers();
		$this->rewrite_class = new CTR_Rewrite();
		$this->media = new CTR_Media();
		$this->seo = new CTR_SEO();
		$this->base_dir = wp_upload_dir()['basedir'] . '/ctr/';

		$CtrDB = new Ctr_DB();
		$this->settings = $CtrDB->getSettings();
	}

	public function init()
	{
		$this->ctrTemplator = new CTR_Templator($this->base_dir . 'public/templates/', $this->base_dir . 'public/cache/');
		$this->ctrTemplator->init();
	}

	public function renderFile($file, $injectData, $viewPath = null)
	{
		$this->ctrTemplator->renderFile($file, $injectData, $viewPath);
	}

	public function getSettings()
	{
		if (null != $this->settings) {
			return $this->settings;
		} else {
			$settings = [];
			$CtrDB = new Ctr_DB();
			$settings = $CtrDB->getSettings();
			$this->settings = $settings;
			return $settings;
		}
	}

	/** Set the query vars in our navigation data array */
	public function setNavigationData($data = null)
	{
		$this->navigation_data = null != $data ? $data : $this->rewrite_class->get_query_vars();
	}

	/** Return the navigation data for usage */
	public function getNavigationData()
	{
		return $this->navigation_data;
	}

	/**
	 * Retrieve neccessary data for the front end based on Rewrite vars
	 */
	public function handleFront($data)
	{
		$ROOT_URL = $this->helpers->getDomain() . '/' . $this->getSettings()['start_url'] . '/';

		$data['start_url'] = $ROOT_URL;
		$data['is_admin'] = (current_user_can('editor') || current_user_can('administrator')) ? true : false;

		$data['vehicle_type'] = isset($data['vehicle_type']) ? $this->helpers->translate_vehicle_type($data['vehicle_type'], 'internal') : null;
		$data['translated_vehicle_type'] = isset($data['vehicle_type']) ? $this->helpers->translate_vehicle_type($data['vehicle_type'], 'auto') : 'cars';
		if (isset($data['ctr_active'])) {

			/**
			 * If we have an AJAX request, we must know it
			 */
			if (isset($data['is_ajax'])) {
				$data['is_ajax'] = true;
			}

			/**
			 * Get media
			 * - First check if the get_media has been set, if so then switch the media type
			 * Then the get_model_media will get the data from the API and will then result in a 301 redirect
			 */
			if (isset($data['ctr_get_media'])) {
				$imgLocation = null;
				$media_size = isset($data['ctr_media_size']) ? $data['ctr_media_size'] : 'medium';
				while ($imgLocation == null) {
					switch ($data['ctr_media_type']) {
						case 'brand':
							$imgLocation = $this->media->get_model_media('brands', $data['ctr_media_id'], $media_size, $data['vehicle_type']);
							break;
						case 'serie':
							$imgLocation = $this->media->get_model_media('series', $data['ctr_media_id'], $media_size, $data['vehicle_type']);
							break;
						case 'model':
							$imgLocation = $this->media->get_model_media('models', $data['ctr_media_id'], $media_size, $data['vehicle_type']);
							break;
					}
				}
				if (null != $imgLocation) {
					header("Location: $imgLocation", true, 301);
				} else {
					return false;
				}
				exit;
			}

			$apiVehicleTypes = new Ctr_VehicleTypes();
			$data['vehicle_types'] = $apiVehicleTypes->getAllTypes();

			// Search API functionality, this functionality will only return JSON
			if (isset($data['ctr_search_term'])) {
				$apiSearch = new Ctr_Search();
				echo json_encode($apiSearch->searchAllData($data['ctr_search_term']));
				exit;
			}

			// The vehicle engine has been set. We can now assume we want the stage data
			// From the stage data we can also fetch all other data
			if (isset($data['vehicle_engine_id'])) {
				// Get Engine Data
				$engine_id = isset($data['vehicle_engine_id']) ? $data['vehicle_engine_id'] : null;
				$engineData = new Ctr_Engines($data['vehicle_type']);
				$engineData = isset($engine_id) ? $engineData->getById($engine_id, 'brand,serie,model,stages,read_methods') : '';
				$data['engine'] = $engineData ?? null;
				$data['brand'] = $engineData['brand'] ?? null;
				$data['serie'] = $engineData['serie'] ?? null;
				$data['model'] = $engineData['model'] ?? null;

				$stages = new Ctr_Stages($data['vehicle_type']);
				$data['stages'] = $stages->getStages($engine_id);
				$stageData = $data['stages'];

				if (!isset($data['stages'])) {
					$data['hasErrors'] = $this->ctrTemplator->returnFile('error', ['errorMessage' => 'An error occured, cannot continue. Maybe you entered an invalid URL?']);
					$data['errors'][] = 'No data for this engine found, please go back to the previous page and select a different engine and then try again';
				} else {
					$data['backUrl'] = ''; //$stageData['url'] = $ROOT_URL . $data['translated_vehicle_type'] . '/' . $data['vehicle_brand'] . '/' . $data['vehicle_serie'] . '/' . $data['vehicle_model'];

					/** Parse and prepare all stage data for sending to Blade template */
					$stageParser = new Ctr_StageData($this->settings);
					$data['stages'] = $stageParser->parseDisplayData($data);
				}
			} else {
				if (!isset($data['vehicle_brand']) && !isset($data['engine']) && null != $data['vehicle_type']) {
					// Get Brands
					$apiBrands = new Ctr_Brands();
					$data['brands'] = $apiBrands->getBrands($data['vehicle_type']);
					$data['backUrl'] = $ROOT_URL;
				}

				/** If a brand is set, get the series */
				if (isset($data['vehicle_brand'])) {
					$apiSeries = new Ctr_Series($data['vehicle_type']);
					$data['series'] = $apiSeries->getSeries(null, $data['vehicle_brand']);
					if (isset($data['series']['brand'])) {
						$data['brand'] = $data['series']['brand'] ?? null;
					}
					if (null == $data['series']) {
						$data['hasErrors'] = $this->ctrTemplator->returnFile('error', ['errorMessage' => 'An error occured, cannot continue. Maybe you entered an invalid URL?']);
						$data['errors'][] = 'No series found, please go back to the previous page and select a brand and then try again';
					} else {
						// Set brand name and image

						unset($data['brands']); // clean up data
					}
					$data['backUrl'] = $ROOT_URL . $data['translated_vehicle_type'];
				}

				// Get Models for Serie
				if (isset($data['vehicle_serie'])) {
					$apiModels = new Ctr_Models($data['vehicle_type']);
					$data['models'] = $apiModels->getModels(null, $data['vehicle_brand'], $data['vehicle_serie']);
					$data['serie'] = $data['models']['serie'] ?? null;
					$data['brand'] = $data['models']['brand'] ?? null;

					if (null == $data['models']) {
						$data['hasErrors'] = $this->ctrTemplator->returnFile('error', ['errorMessage' => 'An error occured, cannot continue. Maybe you entered an invalid URL?']);
						$data['errors'][] = 'No series found, please go back to the previous page and select a brand and then try again';
					} else {
						// Set serie name
						$data['serieId'] = $data['models']['serie']['id'];
						$data['serieName'] = $data['models']['serie']['name'];
						$data['serieSlug'] = $data['models']['serie']['slug'];
						$data['slugVehicleSerie'] = $data['models']['serie']['slug'];
						// Get Serie Image
						$data['serieImage'] = isset($data['serie']['thumbnail']) ? $this->media->get_media_by_url($data['serie']['thumbnail'], $data['vehicle_type']) : $this->media->get_model_media('series', $data['serieId'], 'medium', $data['vehicle_type']);
						$data['backUrl'] = $ROOT_URL . $data['translated_vehicle_type'] . '/' . $data['vehicle_brand'];

						unset($data['series']); // clean up data
					}
				}

				// Get all the engines for a specific model
				if (isset($data['vehicle_model'])) {
					$apiEngines = new Ctr_Engines($data['vehicle_type']);
					$data['engines'] = $apiEngines->getEngines(null, $data['vehicle_brand'], $data['vehicle_serie'], $data['vehicle_model']);

					if (null == $data['engines']) {
						$data['hasErrors'] = $this->ctrTemplator->returnFile('error', ['errorMessage' => 'An error occured, cannot continue. Maybe you entered an invalid URL?']);
						$data['errors'][] = 'No models found, please go back to the previous page and select a different model / model and then try again';
					} else {
						// Set model name
						$data['model'] = $data['engines']['model'];
						$data['serie'] = $data['engines']['serie'];
						$data['brand'] = $data['engines']['brand'];
						$data['backUrl'] = $stageData['url'] = $ROOT_URL . $data['translated_vehicle_type'] . '/' . $data['vehicle_brand'] . '/' . $data['vehicle_serie'];
					}
					unset($data['models']);
				}
			}

			if (isset($data['brand'])) {
				$data['brandImage'] = isset($data['brand']['thumbnail']) ? $this->media->get_media_by_url($data['brand']['thumbnail'], $data['vehicle_type']) : $this->media->get_model_media('brands', $data['brand']['id'], 'medium');
			}
			// Set up SEO Titles
			$this->seo->set_seo_titles($data);
			$data['trailingSlash'] = $this->helpers->getTrailingSlash();
			return $data;
		}
	}

	public function handleAjax($data)
	{
		if (isset($data['vehicle_engine_id'])) {
			$apiStages = new Ctr_Stages($data['vehicle_type']);
			$stageData = $apiStages->getStages($data['vehicle_engine_id']);
			if (isset($stageData) && (is_array($stageData))) {
				$vehicle_type = $this->helpers->translate_vehicle_type($data['vehicle_type']);
				$ROOT_URL = get_home_url() . $this->getSettings()['start_url'];

				$stageData['url'] = $ROOT_URL . $vehicle_type . '/' . $stageData['vehicle']['brand']['slug'] . '/' . $stageData['vehicle']['serie']['slug'] . '/' . $stageData['vehicle']['model']['slug'] . '/' . $stageData['engine']['slug'] . '/' . $stageData['engine']['id'];
			}
			wp_send_json($stageData);
			exit;
		} elseif (isset($data['vehicle_model_id'])) {
			$apiEngines = new Ctr_Engines($data['vehicle_model_id']);
			$engineData = $apiEngines->getEngines($data['vehicle_model_id']);
			wp_send_json($engineData);
			exit;
		} elseif (isset($data['vehicle_serie_id'])) {
			$apiModels = new Ctr_Models($data['vehicle_type']);
			$modelData = $apiModels->getModels($data['vehicle_serie_id']);
			wp_send_json($modelData);
			exit;
		} elseif (isset($data['vehicle_brand_id'])) {
			$apiSeries = new Ctr_Series($data['vehicle_type']);
			$serieData = $apiSeries->getSeries($data['vehicle_brand_id']);
			wp_send_json($serieData);
			exit;
		} elseif (isset($data['vehicle_type'])) {
			$apiBrands = new Ctr_Brands();
			$data['brands'] = $apiBrands->getBrands($data['vehicle_type']);
			wp_send_json($data['brands']);
			exit;
		}
	}
}

$ctrDisplay = new Ctr_Display();
$ctrRewrite = new CTR_Rewrite();
$data = $ctrRewrite->get_query_vars();
$ctrDisplay->init();
$ctrDisplay->setNavigationData($data);
$navigationData = $ctrDisplay->getNavigationData();
$ctrHelpers = new Ctr_Helpers();
$ctrDatabase = new Ctr_DB();
$ctrMedia = new CTR_Media();
$data = $ctrDisplay->handleFront($data);

/**
 * DO NOT REMOVE
 * SET VIEW VARIABLES
 */

$PLUGIN_ROOT_URL    = get_site_url() . '/' . $ctrDisplay->getSettings()['start_url'];
$ASSETS_URL         = content_url('uploads/ctr/assets/');
$MEDIA_URL          = get_site_url() . '/' . $ctrDisplay->getSettings()['start_url'] . '/assets/media/';
$LANGUAGE          	= $ctrDisplay->getSettings()['display_lang'];
$CUSTOM_TPL_PATH	= wp_upload_dir()['basedir'] . '/ctr/custom_templates/';
