<?php

/**
 * Display functionalities
 *
 * This class display functions
 *
 * @since      3.0.0
 * @package    Ctr
 * @subpackage Ctr/includes
 * @author     M Bos <support@chiptuningreseller.com>
 */
require_once plugin_dir_path(dirname(__DIR__)) . 'includes/class-ctr-db.php';
require_once plugin_dir_path(dirname(__DIR__)) . 'includes/class-ctr-helpers.php';
require_once plugin_dir_path(dirname(__DIR__)) . 'includes/class-ctr-media.php';
require_once plugin_dir_path(dirname(__DIR__)) . 'includes/class-ctr-templator.php';

class Ctr_StageData
{
    private $injectData;
    private $helpers;
    private $db;
    private $media;
    private $settings;
	
    public function __construct($settings) {
		$this->helpers = new Ctr_Helpers();
		$this->db = new Ctr_DB();
        $this->media = new CTR_Media();
        $this->settings = $settings;
    }

    public function prepareChartData($data) {
        $chartData = [];
        foreach ($data['stages'] as $stage) {
            if(!isset($this->settings['layout_settings']['graph_display'])) {
                $showGraphForStage = true;
            } else {
                
                $showGraphForStage = ((is_array($stage)) && (isset($this->settings['layout_settings'])) && 
                (isset($this->settings['layout_settings']['graph_display'])) && 
                (isset($this->settings['layout_settings']['graph_display'][$stage['name']]))) 
                ? $this->settings['layout_settings']['graph_display'][$stage['name']] : false;
            }
            if ((isset($stage['name'])) && (strpos($stage['name'], 'dsg') === false && strpos($stage['name'], 'extra') === false && strlen($stage['display_name']) > 1) && $showGraphForStage) {
                $chartData[$stage['name']]['slug'] = $stage['name'];
                $chartData[$stage['name']]['label'] = $stage['display_name'];
                $chartData[$stage['name']]['hpOriginal'] = $data['engine']['hp'];
                $chartData[$stage['name']]['hpData'] = $stage['data']['hp_tuning'];
                $chartData[$stage['name']]['nmOriginal'] = $stage['data']['nm_ori'];
                $chartData[$stage['name']]['nmData'] = $stage['data']['nm_tuning'];

                $chartData[$stage['name']]['dataHpBgColor_tuning'] = $this->helpers->rgbaConverter($this->settings['layout_settings']['graph_colors']['tuning']['hp']) ;
                $chartData[$stage['name']]['dataHpBorderColor_tuning'] = $this->helpers->rgbaConverter($this->settings['layout_settings']['graph_colors']['tuning']['hp']);
                $chartData[$stage['name']]['dataNmBgColor_tuning'] = $this->helpers->rgbaConverter($this->settings['layout_settings']['graph_colors']['tuning']['nm']);
                $chartData[$stage['name']]['dataNmBorderColor_tuning'] =$this->helpers->rgbaConverter($this->settings['layout_settings']['graph_colors']['tuning']['nm']);
                $chartData[$stage['name']]['dataHpBgColor_original'] = $this->settings['layout_settings']['graph_colors']['original']['hp'];
            }
        }
        if(!isset($this->settings['layout_settings']['graph_colors']['tuning']['hp'])) {
            $this->helpers->show_notice('warning', 'You haven\'t set your graph colors. Please add them to show the graphs!', true);
        }
        return $chartData;
    }

    /** Prepare all data for stage display template */
	public function prepareStageData($data)
	{

		$stageData = [];
		$inDevelopment = false;
		$i = 0;
		$stageDisplayData['in_development'] = false;
		foreach ($data as $stage) {
			if (isset($stage['name'])) {

				$showStage = ((isset($this->settings['show_stages'][$stage['name']])) && ($this->settings['show_stages'][$stage['name']] == '1')) ? true : false;
				if (strpos($stage['text_other'], 'in_development') !== false) {
					$inDevelopment = true; // IN DEVELOPMENT ON STAGE LEVEL
				}

				if ($showStage) {
					if (isset($stage['media'])) {
						$stageData[$i]['media'] = $stage['media'];
					}
					if (isset($stage['content'])) {
						$stageData[$i]['content'] = $stage['content'];
					}
                    
					if (strpos($stage['name'], 'dsg') === false && strpos($stage['name'], 'extra') === false) {
                        
						$stageData['hp_ori'] = round($stage['data']['hp_ori']);
						$stageData['nm_ori'] = round($stage['data']['nm_ori']);
                        
						if (!$inDevelopment) {
							$stageData[$i]['hideStage'] = '';
							$stageData[$i]['name'] = $stage['name'];
							$stageData[$i]['display_name'] = $stage['display_name'];
							$stageData[$i]['hp_ori'] = round($stage['data']['hp_ori']);
							$stageData[$i]['hp_tuning'] = $stage['data']['hp_tuning'] > 0 ? $stage['data']['hp_tuning'] : '-';
							$stageData[$i]['hp_tuning_increase'] = $stage['data']['hp_tuning'] > 0 ? $stage['data']['hp_tuning'] -  $stage['data']['hp_ori'] : '-';
							$stageData[$i]['nm_ori'] = isset($stage['data']['nm_ori']) ? $stage['data']['nm_ori'] : '-';
							$stageData[$i]['nm_tuning'] = $stage['data']['nm_tuning'] > 0 ? $stage['data']['nm_tuning'] : '-';
							$stageData[$i]['nm_tuning_increase'] = $stage['data']['nm_tuning'] > 0 ? $stage['data']['nm_tuning'] -  $stage['data']['nm_ori'] : '-';
							$stageData[$i]['nm_tuning_increase_percentage'] = $this->helpers->calculatePercentageIncrease($stage['data']['nm_ori'], $stage['data']['nm_tuning']);
							$stageData[$i]['kw_ori'] = round($stage['data']['hp_ori'] * 0.745699872);
							$stageData[$i]['kw_tuning'] = $stage['data']['hp_tuning'] > 0 ? round($stage['data']['hp_tuning'] * 0.745699872) : '-';
							$stageData[$i]['kw_tuning'] = $stage['data']['hp_tuning'] > 0 ? round($stage['data']['hp_tuning'] * 0.745699872) : '-';
							$stageData[$i]['kw_tuning_increase'] = $stage['data']['hp_tuning'] > 0 ? round($stage['data']['hp_tuning'] * 0.745699872) - round($stage['data']['hp_ori'] * 0.745699872) : '-';
							$stageData[$i]['kw_tuning_increase_percentage'] = $this->helpers->calculatePercentageIncrease($stage['data']['hp_ori'], $stage['data']['hp_tuning']);
							$stageData[$i]['show_price'] = $this->settings['show_price'];
							// $stageData[$i]['price'] = ((isset($this->settings['fixed_stage_prices'][$data['vehicle']['brand']['type']][$stage['name']])) && (strlen($this->settings['fixed_stage_prices'][$data['vehicle']['brand']['type']][$stage['name']]) > 0)) ? $this->settings['fixed_stage_prices'][$data['vehicle']['brand']['type']][$stage['name']] : $stage['price'];
						} else {
							$stageDisplayData['in_development'] = true;
						}
					}
					$i++;
				}
			}
		}
        

		return $stageData;
	}

    public function parseDisplayData($data)
    {
        
        $this->settings['connection_valid'] = $this->helpers->check_api_connection();
        
        $stageContent = [];
        $stageMedia = [];
        $stageMediaData = [];
        $imageGalleryData = '';
        $dataStageTableButtons = [];
        $hideStage = '';
        $vehicleName = $data['brand']['name'] . ' ' . $data['serie']['name'] . ' (' . $data['model']['name'] . ') ' . $data['engine']['name'] . ' ' . $this->helpers->translate_fuel_type('lbl_fuel_' . $data['engine']['fuel_type'], $this->settings['display_lang']);
        $inDevelopment = false;
        $i = 0; $numberOfStages = 0;
        $internalVehicleType = isset($data['vehicle_type']) ? $data['vehicle_type'] : 'cars';
        /** Check if the SERIE is set and add serie images where possible */
        
        if (isset($data['serie'])) {
            $serie = $data['serie'];
            if ((isset($serie['media'])) && (count($serie['media']) > 0)) {
                foreach($serie['media'] as $serieMediaItem) {
                    $mdSrc = $this->media->get_media($serieMediaItem['id'], 'series', $internalVehicleType, 'large');
                    $imageGalleryData .= '<div class="col"><a href="' . $mdSrc . '"><img class="stageImage col pull-left rounded mx-auto" src="' . $mdSrc . '" alt="' . $vehicleName . '" title="' . $vehicleName . '"></a></div>';
                }
            } else {
                $masterImage = $this->media->get_model_media('series', $serie['id'], 'large', $internalVehicleType);
                if ($masterImage) {
                    $imageGalleryData .= '<img class="stageImage rounded mx-auto" src="' . $masterImage . '" alt="' . $vehicleName . '" title="' . $vehicleName . '">';
                } elseif (!$masterImage) {
                    $noImage = $this->helpers->getAssetsUrl() . $internalVehicleType . '_placeholder.png';
                    $imageGalleryData .= '<img class="stageNoImage rounded mx-auto d-block" src="' . $noImage . '" alt="' . $vehicleName . '" title="' . $vehicleName . '">';
                }
            }
        }
        if(isset($data['engine'])) {
            $nm_ori = $this->helpers->array_key_search_r($data['stages'], 'nm_ori');
            if(isset($nm_ori)) {
                $data['engine']['nm'] = $nm_ori;
            }
            unset($data['engine']['stages']); // stage data not needed in engine
        }
        
        /** Prepare the stages for display **/
        foreach ($data['stages'] as &$stage) {
            if(isset($stage['name'])) {
                if(strpos($stage['name'], 'dsg') !== false) {
                    $stage['name'] = 'stage_dsg';
                }
                
                $stage['show'] = ((isset($this->settings['show_stages'][$stage['name']])) && ($this->settings['show_stages'][$stage['name']] == '1')) ? true : false;
                $stage['hideCss'] = $hideStage;
                $stage['price'] = (isset($this->settings['fixed_stage_prices'][$data['brand']['type']][$stage['name']]) && ($this->settings['fixed_stage_prices'][$data['brand']['type']][$stage['name']] > 0))  ? $this->settings['fixed_stage_prices'][$data['brand']['type']][$stage['name']] : $stage['price'];
                
                $stage['in_development'] = strpos($stage['text_other'], 'in_development') !== false ? true : false;

                if (is_array($stage['data'])) {
                    $stage['hp_percentage_increase'] = isset($stage['data']['hp_tuning']) ? $this->helpers->calculatePercentageIncrease($stage['data']['hp_ori'], $stage['data']['hp_tuning']) : null;
                    $stage['nm_percentage_increase'] = isset($stage['data']['nm_tuning']) ? $this->helpers->calculatePercentageIncrease($stage['data']['nm_ori'], $stage['data']['nm_tuning']) : null;
                    if (isset($stage['media'])) {
                        array_push($stageMedia, $stage['media']);
                    }
                    if (isset($stage['content'])) {
                        array_push($stageContent, $stage['content']);
                    }

                    /*** Render the Basic Stage Table data to be inserted in the template */
                    if (isset($this->settings['layout_settings']['show_basic_table'])) {
                        if (!isset($stage['name']) || strpos($stage['name'], 'extra') !== false) {
                            // No stage name set or special item, don't do anything
                        } else {
                            $stage['name'] = stripos($stage['name'], 'dsg') !== false ? 'stage_dsg' : $stage['name'];

                            $showStage = ((isset($this->settings['show_stages'][$stage['name']])) && ($this->settings['show_stages'][$stage['name']] == '1')) ? true : false;
                            if($showStage) {
                                $numberOfStages++;
                                $dataStageTableButtons[$i]['name'] = $stage['name'];
                                $dataStageTableButtons[$i]['fuel_type'] = $data['engine']['fuel_type'];
                                $dataStageTableButtons[$i]['display_name'] = $stage['display_name'];
                                $dataStageTableButtons[$i]['hp_increase'] = (isset($stage['data']['hp_tuning']) && isset($stage['data']['hp_ori'])) ? $stage['data']['hp_tuning'] - $stage['data']['hp_ori'] : '';
                                $hideStage = ' hideStage';
                            }
                        }
                        
                    }
                    $i++;

                }
                if (strpos($stage['text_other'], 'in_development') !== false) {
                    $inDevelopment = true; // IN DEVELOPMENT ON STAGE LEVEL
                }
            }
        }

        if(isset($stageMedia[0])) {
            foreach ($stageMedia[0] as $image) {
                $src = $this->media->get_media($image['id'], 'stages', NULL, 'large');
                $stageMediaData[] = '<div class="col stageImage"><a href="' . $src . '"><img class="stageSmallImage" src="' . $src . '" alt="' . $image[0]['name'] . '" data-caption="" data-src="' . $src . '" data-large_image="' . $src . '" ></a></div>';
            }
        }
        $graphsEnabledApi = ((isset($this->helpers->check_api_connection()['subscriptions'])) && (in_array('premium', $this->helpers->check_api_connection()['subscriptions']))) ? true : false;
        $showBarChart = ($graphsEnabledApi && isset($this->settings['layout_settings']['show_graph']['barchart']) && !$inDevelopment) ? true : false;
        $showLineChart = ($graphsEnabledApi && isset($this->settings['layout_settings']['show_dyno']) && !$inDevelopment) ? true : false;
        $showPieChart = ($graphsEnabledApi && isset($this->settings['layout_settings']['show_graph']['piechart']) && !$inDevelopment) ? true : false;
        if($showBarChart || $showLineChart || $showPieChart) {
            $chartData = $this->prepareChartData($data);
        } else {
            $chartData = '';
        }
        
        $showBasicTable = isset($this->settings['layout_settings']['show_basic_table']) ?? false;
        $showIncreaserTable = isset($this->settings['layout_settings']['show_increaser_table']) ?? false;
        $showEcuDetails = isset($this->settings['layout_settings']['show_ecu_info']) ?? false;
        $showPrices = ((isset($this->settings['show_price'])) && ($this->settings['show_price'] == 1)) ? true : false;
        $ecuDetails = (isset($data['stages']['vehicle']['ecudetails'])) ? $data['stages']['vehicle']['ecudetails'] : [];
        $in_development = false;
        if((is_array($data['stages'])) && (count($data['stages']) == 0)) {
            $in_development = true;
        }
        
        return [
            'isFirstButton' => 'active',
            'stageDisplayData' => $this->prepareStageData($data['stages']),
            'ecuDetails' => $ecuDetails,
            'urlAssets' => $this->helpers->getAssetsUrl(),
            'configShowBasicTable' => $showBasicTable,
            'configShowIncreaserTable' => $showIncreaserTable,
            'configShowEcuDetails' => $showEcuDetails,
            'configShowBarChart' => $showBarChart,
            'configShowLineChart' => $showLineChart,
            'configShowPieChart' => $showPieChart,
            'dataBrand' => $data['brand'],
            'dataEngine' => $data['engine'],
            'dataStages' => $data['stages'],
            'dataBasicTableButtons' => $dataStageTableButtons,
            'showPrices' => $showPrices,
            'dataStageMedia' => $stageMediaData,
            'dataStageContent' => $stageContent,
            'backUrl' => $data['backUrl'],
            'dataImageGallery' => $imageGalleryData,
            'dataShortcode' => str_replace('%VEHICLE_DATA%', $vehicleName, do_shortcode(stripslashes($this->settings['stage_text']))),
            'dataCharts' => $chartData,
            'numberOfStages' => $numberOfStages > 0 ? $numberOfStages : 1,
            'imgBrandImage' => isset($data['brandImage']) ? $data['brandImage'] : '',
            'engineFuelType' => $this->helpers->translate_fuel_type('lbl_fuel_' . $data['engine']['fuel_type'], $this->settings['display_lang']),
            'engineId' =>  $data['engine']['id'],
            'engineHpOriginal' =>  $data['engine']['hp'],
            /** Labels and texts */
            'lblPageTitle' => esc_html__("Chiptuning for", 'ctr'),
            'lblSubtitle' => esc_html__("Chiptuning for", 'ctr'),
            'lblVehicleBrandName' => $data['brand']['name'],
            'lblVehicleSerieName' => $data['serie']['name'],
            'lblVehicleModelName' => $data['model']['name'],
            'lblVehicleEngineName' => $data['engine']['name'],
            'lblStandardText' => esc_html__("Standard", 'ctr'),
            'lblStageText' => esc_html__("Stage", 'ctr'),
            'lblDifference' => esc_html__("Difference", 'ctr'),
            'lblPower' => esc_html__('Power (HP)', 'ctr'),
            'lblPowerShort' => esc_html__('HP', 'ctr'),
            'lblTorque' => esc_html__('Torque (Nm)', 'ctr'),
            'lblTorqueShort' => esc_html__('Nm', 'ctr'),
            'lblKilowatt' => esc_html__("Kilowatt (KW)", 'ctr'),
            'lblShortKilowatt' => esc_html__("KW", 'ctr'),
            'lblCurrency' => $this->settings['currency'],
            'lblAskForPrice' => esc_html__("Ask for price", 'ctr'),
            'lblInDevelopment' => esc_html__("In development", 'ctr'),
            'lblPrice' => esc_html__("Price", 'ctr'),
            'lblFuelType' =>  esc_html__("Fuel type", 'ctr'),
            'lblVehicleType' => $data['vehicle_type'],
            'lblVehicleTypeInternal' => $internalVehicleType,
            'isInDevelopment' => $in_development,
            'lblStillInDevelopmentResultsMayVary' => esc_html__("This item is still in development, the results may vary or tuning may not be possible at all. Contact us for more information.", 'ctr'),
        ];
    }

    public function getData() {
        return $this->injectData;
    }
}
