<?php

/**
 * Provide a public-facing view for the plugin
 *
 * This file is used to markup the public-facing aspects of the plugin.
 *
 * @link       https://www.chiptuningreseller.com
 * @since      3.0.0
 *
 * @package    Ctr
 * @subpackage Ctr/public/partials
 */

 // For AJAX calls, we want a minimum set of code to load as fast as possible
if (get_query_var('ajax', false) === 'true') {
	require_once plugin_dir_path(dirname(__FILE__)) . 'includes/class-ctr-ajax.php';
	$ctrAjax = new Ctr_Ajax();
	$ctrAjax->handleAjax($data);
	exit;
}
$CUSTOM_TPL_PATH	= wp_upload_dir()['basedir'] . '/ctr/custom_templates/';
// This file is required - it will load all neccessary data that is being used in the display
require_once plugin_dir_path(dirname(__FILE__)) . 'includes/class-ctr-display.php';
echo get_header();
require_once plugin_dir_path(dirname(__FILE__)) . 'partials/ctr-public-header.php';

if((isset($data['is_admin'])) && ($data['is_admin'] == true)) {
    // Flush the Cache on Request
    if ( get_query_var('ctr_flush_cache') ) {
        require_once plugin_dir_path(dirname(__DIR__)) . 'admin/class-ctr-admin-front.php';
        $adminFront = new Ctr_Admin_Front();
        $flushCacheMsg = $adminFront->flush_cache();
        if($flushCacheMsg) {
            echo '<script>alert(\'' . $flushCacheMsg . '\');window.history.replaceState({}, location.protocol + \'//\' + location.host + location.pathname, "/");</script>';
        }
    }
    require_once plugin_dir_path(dirname(__FILE__)) . 'partials/ctr-public-admin-header.php';
}

?>
<div class="ctr-bootstrap chiptuningreseller-container <?php if (isset($data['dataStages'])) { ?> stage-page <?php } ?> container">
    <?php
    if(isset($data['hasErrors'])) {
        $data['error_image'] = get_site_url() . '/wp-content/uploads/ctr/assets/404-error.png';
        require_once plugin_dir_path(dirname(__FILE__)) . 'partials/ctr-public-errors.php';
    } else {
        if ((isset($ctrSettings['layout_settings']['show_selector'])) && ($ctrSettings['layout_settings']['show_selector']) == 'selector') {
            require_once CTR_PLUGIN_DIR . 'public/modules/dropdown-selector.module.php';
            $dropdownModule = new Ctr_Module_DropdownSelector($ctrSettings);
            echo $dropdownModule->show_dropdown();
            // require_once plugin_dir_path(dirname(__FILE__)) . 'partials/ctr-public-selector.php';
        } elseif ((isset($ctrSettings['layout_settings']['show_selector'])) && ($ctrSettings['layout_settings']['show_selector']) == 'iconcrumbs') {
            require_once plugin_dir_path(dirname(__FILE__)) . 'partials/ctr-public-iconcrumbs.php';
        }
        if (isset($data['stages']) && isset($data['get_quote'])) {
            require_once plugin_dir_path(dirname(__FILE__)) . 'partials/ctr-public-quote.php';
            return;
        }
        if (isset($data['stages'])) {
            if (isset($data['is_ajax'])) {
                return $data['stages'];
            }
            require_once plugin_dir_path(dirname(__FILE__)) . 'partials/ctr-public-stages.php';
        } elseif (isset($data['engines'])) {
            
            if (isset($data['is_ajax'])) {
                return $data['engines'];
            }
            require_once plugin_dir_path(dirname(__FILE__)) . 'partials/ctr-public-engines.php';
        } elseif (isset($data['models'])) {
            if (isset($data['is_ajax'])) {
                return $data['models'];
            }
            require_once plugin_dir_path(dirname(__FILE__)) . 'partials/ctr-public-models.php';
        } elseif (isset($data['series'])) {
            if (isset($data['is_ajax'])) {
                return $data['series'];
            }
            require_once plugin_dir_path(dirname(__FILE__)) . 'partials/ctr-public-series.php';
        } elseif (isset($data['brands'])) {
            if (isset($data['is_ajax'])) {
                return $data['brands'];
            }
            require_once plugin_dir_path(dirname(__FILE__)) . 'partials/ctr-public-brands.php';
        } elseif (isset($data['vehicle_types'])) {
            if (isset($data['is_ajax'])) {
                return $data['vehicle_types'];
            }
            require_once plugin_dir_path(dirname(__FILE__)) . 'partials/ctr-public-vehicle-types.php';
        }
    }
    ?>
</div>
<?php

if (isset($ctrSettings['layout_settings']['show_sidebar'])) {
    get_sidebar();
}
require_once plugin_dir_path(dirname(__FILE__)) . 'partials/ctr-public-footer.php';

echo get_footer();
?>